@@ -412,7 +412,7 @@ import argparse
 import os
 from fnmatch import fnmatch
 from glob import glob
-from typing import List
+from typing import Any, Dict, List
 
 # External imports
 from tornado.autoreload import watch
@@ -727,6 +727,13 @@ class Serve(Subcommand):
         )),
     )
 
+    def customize_kwargs(self, args: argparse.Namespace, server_kwargs: Dict[str, Any]) -> Dict[str, Any]:
+        '''Allows subclasses to customize ``server_kwargs``.
+
+        Should modify and return a copy of the ``server_kwargs`` dictionary.
+        '''
+        return dict(server_kwargs)
+
     def invoke(self, args: argparse.Namespace) -> None:
         '''
 
@@ -867,6 +874,8 @@ class Serve(Subcommand):
             find_autoreload_targets(args.files[0])
             add_optional_autoreload_files(args.dev)
 
+        server_kwargs = self.customize_kwargs(args, server_kwargs)
+
         with report_server_init_errors(**server_kwargs):
             server = Server(applications, **server_kwargs)
 
