@@ -1,17 +1,85 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Various kinds of data table (data grid) widgets.
 
 '''
-from __future__ import absolute_import
 
-from ...core.enums import DateFormat, FontStyle, NumeralLanguage, TextAlign, RoundingFunction
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+import logging # isort:skip
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Bokeh imports
+from ...core.enums import (
+    DateFormat,
+    FontStyle,
+    NumeralLanguage,
+    RoundingFunction,
+    TextAlign,
+)
 from ...core.has_props import abstract
-from ...core.properties import Bool, Color, Either, Enum, Float, Instance, Int, List, Override, String
+from ...core.properties import (
+    Bool,
+    Color,
+    Either,
+    Enum,
+    Float,
+    Instance,
+    Int,
+    List,
+    Override,
+    String,
+)
 from ...model import Model
-
-from ..sources import DataSource, CDSView
-
+from ..sources import CDSView, DataSource
 from .widget import Widget
 
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'AvgAggregator',
+    'BooleanFormatter',
+    'CellFormatter',
+    'CellEditor',
+    'CheckboxEditor',
+    'DataCube',
+    'DataTable',
+    'DateEditor',
+    'DateFormatter',
+    'GroupingInfo',
+    'HTMLTemplateFormatter',
+    'IntEditor',
+    'MaxAggregator',
+    'MinAggregator',
+    'NumberEditor',
+    'NumberFormatter',
+    'PercentEditor',
+    'ScientificFormatter',
+    'SelectEditor',
+    'StringEditor',
+    'StringFormatter',
+    'SumAggregator',
+    'TableColumn',
+    'TableWidget',
+    'TextEditor',
+    'TimeEditor',
+)
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
 @abstract
 class CellFormatter(Model):
     ''' Abstract base class for data table's cell formatters.
@@ -24,6 +92,19 @@ class CellEditor(Model):
 
     '''
 
+@abstract
+class RowAggregator(Model):
+    ''' Abstract base class for data cube's row formatters.
+
+    '''
+    field_ = String('', help="""
+    Refers to the table column being aggregated
+    """)
+
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 class StringFormatter(CellFormatter):
     ''' Basic string cell formatter.
 
@@ -42,6 +123,24 @@ class StringFormatter(CellFormatter):
     details.
     """)
 
+class ScientificFormatter(StringFormatter):
+    ''' Display numeric values from continuous ranges as "basic numbers",
+    using scientific notation when appropriate by default.
+    '''
+    precision = Int(10, help="""
+    How many digits of precision to display.
+    """)
+
+    power_limit_high = Int(5, help="""
+    Limit the use of scientific notation to when::
+        log(x) >= power_limit_high
+    """)
+
+    power_limit_low = Int(-3, help="""
+    Limit the use of scientific notation to when::
+        log(x) <= power_limit_low
+    """)
+
 class NumberFormatter(StringFormatter):
     ''' Number cell formatter.
 
@@ -443,6 +542,26 @@ class DateEditor(CellEditor):
 
     '''
 
+class AvgAggregator(RowAggregator):
+    ''' Simple average across multiple rows.
+
+    '''
+
+class MinAggregator(RowAggregator):
+    ''' Smallest value across multiple rows.
+
+    '''
+
+class MaxAggregator(RowAggregator):
+    ''' Largest value across multiple rows.
+
+    '''
+
+class SumAggregator(RowAggregator):
+    ''' Simple sum across multiple rows.
+
+    '''
+
 class TableColumn(Model):
     ''' Table column widget.
 
@@ -498,7 +617,7 @@ class TableWidget(Widget):
     """)
 
     def __init__(self, **kw):
-        super(TableWidget, self).__init__(**kw)
+        super().__init__(**kw)
         if "view" not in kw:
             self.view = CDSView(source=self.source)
 
@@ -575,8 +694,47 @@ class DataTable(TableWidget):
     Whether to show a header row with column names at the top of the table.
     """)
 
+    width = Override(default=600)
+
     height = Override(default=400)
 
     row_height = Int(25, help="""
     The height of each row in pixels.
     """)
+
+class GroupingInfo(Model):
+    '''Describes how to calculate totals and sub-totals
+    '''
+
+    getter = String('', help="""
+    References the column which generates the unique keys of this sub-total (groupby).
+    """)
+
+    aggregators = List(Instance(RowAggregator), help="""
+    Describes how to aggregate the columns which will populate this sub-total.
+    """)
+
+    collapsed = Bool(False, help="""
+    Whether the corresponding sub-total is expanded or collapsed by default.
+    """)
+
+class DataCube(DataTable):
+    '''Specialized DataTable with collapsing groups, totals, and sub-totals.
+    '''
+
+    grouping = List(Instance(GroupingInfo), help="""
+    Describe what aggregation operations used to define sub-totals and totals
+    """)
+
+    target = Instance(DataSource, help="""
+    Two column datasource (row_indices & labels) describing which rows of the
+    data cubes are expanded or collapsed
+    """)
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
